Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExampleCommand ¶ added in v0.15.0
func ExampleCommand()
ExampleCommand demonstrates using CommandInterface which implements RunnableInterface to run on nodes and inventories.
func ExampleCommandInventory ¶ added in v0.15.0
func ExampleCommandInventory()
ExampleCommandInventory demonstrates running commands on an inventory (multiple nodes).
func ExampleCommandNotRequired ¶ added in v0.15.0
func ExampleCommandNotRequired()
ExampleCommandNotRequired demonstrates using WithRequired(false) to allow execution to continue even if the command fails.
func ExampleCommandWithArgs ¶ added in v0.15.0
func ExampleCommandWithArgs()
ExampleCommandWithArgs demonstrates that commands can use args like other runnables.
func ExampleCommandWithBecome ¶ added in v0.15.0
func ExampleCommandWithBecome()
ExampleCommandWithBecome demonstrates using WithBecomeUser to run commands as a different user (e.g., postgres, www-data).
func ExampleCommandWithChdir ¶ added in v0.15.0
func ExampleCommandWithChdir()
ExampleCommandWithChdir demonstrates using WithChdir to run commands in a specific working directory.
func NewExamplePlaybook ¶
func NewExamplePlaybook() types.RunnableInterface
NewExamplePlaybook creates a new example playbook.
Types ¶
type ExamplePlaybook ¶
type ExamplePlaybook struct {
*types.BasePlaybook
}
ExamplePlaybook demonstrates a basic playbook that runs multiple skills in sequence. This playbook checks system status and updates if needed.
func (*ExamplePlaybook) Run ¶
func (e *ExamplePlaybook) Run() types.Result
Run executes the playbook with custom orchestration logic.