examples

package
v0.13.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 22, 2026 License: AGPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewExamplePlaybook

func NewExamplePlaybook() types.RunnableInterface

NewExamplePlaybook creates a new example playbook.

Types

type ExamplePlaybook

type ExamplePlaybook struct {
	*types.BasePlaybook
}

ExamplePlaybook demonstrates a basic playbook that runs multiple skills in sequence. This playbook checks system status and updates if needed.

func (*ExamplePlaybook) Run

func (e *ExamplePlaybook) Run() types.Result

Run executes the playbook with custom orchestration logic.

Jump to